@@ -1,3 +1,5 @@
+# vim: tabstop=4 shiftwidth=4 softtabstop=4
+
 # Copyright 2012 NEC Corporation
 #
 #    Licensed under the Apache License, Version 2.0 (the "License"); you may
@@ -12,18 +14,15 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from django.urls import re_path
+from django.conf.urls import patterns  # noqa
+from django.conf.urls import url  # noqa
 
-from openstack_dashboard.dashboards.admin.networks.ports import views
-from openstack_dashboard.dashboards.admin.networks.ports.extensions. \
-    allowed_address_pairs import views as addr_pairs_views
+from openstack_dashboard.dashboards.project.networks.ports import views
 
 PORTS = r'^(?P<port_id>[^/]+)/%s$'
+VIEW_MOD = 'openstack_dashboard.dashboards.admin.networks.ports.views'
 
 
-urlpatterns = [
-    re_path(PORTS % 'detail', views.DetailView.as_view(), name='detail'),
-    re_path(PORTS % 'addallowedaddresspairs',
-            addr_pairs_views.AddAllowedAddressPair.as_view(),
-            name='addallowedaddresspairs'),
-]
+urlpatterns = patterns(VIEW_MOD,
+    url(PORTS % 'detail', views.DetailView.as_view(), name='detail')
+)
