@@ -14,6 +14,7 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+from django.conf import settings
 from django.utils.translation import ugettext_lazy as _
 
 from horizon import exceptions
@@ -44,7 +45,7 @@ class LogTab(tabs.Tab):
             data = api.nova.server_console_output(request,
                                                   instance.id,
                                                   tail_length=35)
-        except:
+        except Exception:
             data = _('Unable to get log for instance "%s".') % instance.id
             exceptions.handle(request, ignore=True)
         return {"instance": instance,
@@ -61,21 +62,62 @@ class ConsoleTab(tabs.Tab):
         instance = self.tab_group.kwargs['instance']
         # Currently prefer VNC over SPICE, since noVNC has had much more
         # testing than spice-html5
-        try:
-            console = api.nova.server_vnc_console(request, instance.id)
-            console_url = "%s&title=%s(%s)" % (
-                console.url,
-                getattr(instance, "name", ""),
-                instance.id)
-        except:
+        console_type = getattr(settings, 'CONSOLE_TYPE', 'AUTO')
+        if console_type == 'AUTO':
+            try:
+                console = api.nova.server_vnc_console(request, instance.id)
+                console_url = "%s&title=%s(%s)" % (
+                    console.url,
+                    getattr(instance, "name", ""),
+                    instance.id)
+            except Exception:
+                try:
+                    console = api.nova.server_spice_console(request,
+                                                            instance.id)
+                    console_url = "%s&title=%s(%s)" % (
+                        console.url,
+                        getattr(instance, "name", ""),
+                        instance.id)
+                except Exception:
+                    try:
+                        console = api.nova.server_rdp_console(request,
+                                                              instance.id)
+                        console_url = "%s&title=%s(%s)" % (
+                            console.url,
+                            getattr(instance, "name", ""),
+                            instance.id)
+                    except Exception:
+                        console_url = None
+        elif console_type == 'VNC':
+            try:
+                console = api.nova.server_vnc_console(request, instance.id)
+                console_url = "%s&title=%s(%s)" % (
+                    console.url,
+                    getattr(instance, "name", ""),
+                    instance.id)
+            except Exception:
+                console_url = None
+        elif console_type == 'SPICE':
             try:
                 console = api.nova.server_spice_console(request, instance.id)
                 console_url = "%s&title=%s(%s)" % (
                     console.url,
                     getattr(instance, "name", ""),
                     instance.id)
-            except:
+            except Exception:
                 console_url = None
+        elif console_type == 'RDP':
+            try:
+                console = api.nova.server_rdp_console(request, instance.id)
+                console_url = "%s&title=%s(%s)" % (
+                    console.url,
+                    getattr(instance, "name", ""),
+                    instance.id)
+            except Exception:
+                console_url = None
+        else:
+            console_url = None
+
         return {'console_url': console_url, 'instance_id': instance.id}
 
 
