@@ -1,3 +1,5 @@
+# vim: tabstop=4 shiftwidth=4 softtabstop=4
+
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
 # a copy of the License at
@@ -10,10 +12,10 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
-from mox3.mox import IgnoreArg  # noqa
-from mox3.mox import IsA  # noqa
+from mox import IsA  # noqa
 
 from django.core.urlresolvers import reverse
+from django.core.urlresolvers import reverse_lazy
 from django import http
 
 from horizon.workflows import views
@@ -33,7 +35,7 @@ class LoadBalancerTests(test.TestCase):
             self[attr] = value
 
     DASHBOARD = 'project'
-    INDEX_URL = reverse('horizon:%s:loadbalancers:index' % DASHBOARD)
+    INDEX_URL = reverse_lazy('horizon:%s:loadbalancers:index' % DASHBOARD)
 
     ADDPOOL_PATH = 'horizon:%s:loadbalancers:addpool' % DASHBOARD
     ADDVIP_PATH = 'horizon:%s:loadbalancers:addvip' % DASHBOARD
@@ -67,13 +69,7 @@ class LoadBalancerTests(test.TestCase):
         # retrieves monitors
         api.lbaas.pool_health_monitor_list(
             IsA(http.HttpRequest), tenant_id=self.tenant.id).MultipleTimes() \
-            .AndReturn(self.monitors.list())
-
-        api.network.floating_ip_supported(IgnoreArg()).MultipleTimes() \
-            .AndReturn(True)
-
-        api.network.floating_ip_simple_associate_supported(IgnoreArg()).MultipleTimes() \
-            .AndReturn(True)
+                .AndReturn(self.monitors.list())
 
     def set_up_expect_with_exception(self):
         api.lbaas.pool_list(
@@ -87,18 +83,10 @@ class LoadBalancerTests(test.TestCase):
             .AndRaise(self.exceptions.neutron)
 
     @test.create_stubs({api.lbaas: ('pool_list', 'member_list',
-                                    'pool_health_monitor_list'),
-                        api.network: ('floating_ip_supported',
-                                      'floating_ip_simple_associate_supported',
-                                      'tenant_floating_ip_list')
-                        })
+                                    'pool_health_monitor_list')})
     def test_index_pools(self):
-        fips = self.floating_ips.list()
         self.set_up_expect()
 
-        api.network.tenant_floating_ip_list(IsA(http.HttpRequest)).\
-            AndReturn(fips)
-
         self.mox.ReplayAll()
 
         res = self.client.get(self.INDEX_URL)
@@ -110,18 +98,10 @@ class LoadBalancerTests(test.TestCase):
                          len(self.pools.list()))
 
     @test.create_stubs({api.lbaas: ('pool_list', 'member_list',
-                                    'pool_health_monitor_list'),
-                        api.network: ('floating_ip_supported',
-                                      'floating_ip_simple_associate_supported',
-                                      'tenant_floating_ip_list')
-                        })
+                                    'pool_health_monitor_list')})
     def test_index_members(self):
-        fips = self.floating_ips.list()
         self.set_up_expect()
 
-        api.network.tenant_floating_ip_list(IsA(http.HttpRequest)).\
-            AndReturn(fips)
-
         self.mox.ReplayAll()
 
         res = self.client.get(self.INDEX_URL + '?tab=lbtabs__members')
@@ -130,21 +110,13 @@ class LoadBalancerTests(test.TestCase):
                                 % self.DASHBOARD)
         self.assertTemplateUsed(res, 'horizon/common/_detail_table.html')
         self.assertEqual(len(res.context['memberstable_table'].data),
-                         len(self.members.list()))
+                              len(self.members.list()))
 
     @test.create_stubs({api.lbaas: ('pool_list', 'member_list',
-                                    'pool_health_monitor_list'),
-                        api.network: ('floating_ip_supported',
-                                      'floating_ip_simple_associate_supported',
-                                      'tenant_floating_ip_list')
-                        })
+                                    'pool_health_monitor_list')})
     def test_index_monitors(self):
-        fips = self.floating_ips.list()
         self.set_up_expect()
 
-        api.network.tenant_floating_ip_list(IsA(http.HttpRequest)).\
-            AndReturn(fips)
-
         self.mox.ReplayAll()
 
         res = self.client.get(self.INDEX_URL + '?tab=lbtabs__monitors')
@@ -153,7 +125,7 @@ class LoadBalancerTests(test.TestCase):
                                 % self.DASHBOARD)
         self.assertTemplateUsed(res, 'horizon/common/_detail_table.html')
         self.assertEqual(len(res.context['monitorstable_table'].data),
-                         len(self.monitors.list()))
+                              len(self.monitors.list()))
 
     @test.create_stubs({api.lbaas: ('pool_list', 'member_list',
                                     'pool_health_monitor_list')})
@@ -294,61 +266,33 @@ class LoadBalancerTests(test.TestCase):
             self.assertContains(res, default_provider)
 
     def test_add_vip_post(self):
-        self._test_add_vip_common_post()
+        self._test_add_vip_post()
 
     def test_add_vip_post_no_connection_limit(self):
-        self._test_add_vip_common_post(with_conn_limit=False)
-
-    def test_add_vip_post_with_diff_subnet(self):
-        self._test_add_vip_common_post(with_diff_subnet=True)
-
-    def test_add_v6_vip_post(self):
-        self._test_add_vip_common_post(vip_name='v6_vip1',
-                                       subnet_name='v6_subnet1',
-                                       pool_name='v6_pool1')
-
-    def test_add_v6_vip_post_no_connection_limit(self):
-        self._test_add_vip_common_post(vip_name='v6_vip1',
-                                       subnet_name='v6_subnet1',
-                                       pool_name='v6_pool1',
-                                       with_conn_limit=False)
-
-    def test_add_v6_vip_post_with_diff_subnet(self):
-        self._test_add_vip_common_post(vip_name='v6_vip1',
-                                       subnet_name='v6_subnet1',
-                                       pool_name='v6_pool1',
-                                       with_diff_subnet=True)
+        self._test_add_vip_post(with_conn_limit=False)
 
     @test.create_stubs({api.lbaas: ('pool_get', 'vip_create'),
-                        api.neutron: (
-                            'network_list_for_tenant', 'subnet_get', )})
-    def _test_add_vip_common_post(self, vip_name='vip1',
-                                  subnet_name='mysubnet1',
-                                  pool_name='pool1',
-                                  with_diff_subnet=False,
-                                  with_conn_limit=True):
-        """This method is common for both IPv4 and IPv6 tests. For IPv6 test
-           we will pass the corresponding vip_name, subnet_name & pool_name.
-        """
-        vip = self.vips.get(name=vip_name)
+                        api.neutron: ('subnet_get', )})
+    def _test_add_vip_post(self, with_conn_limit=True):
+        vip = self.vips.first()
+
+        subnet = self.subnets.first()
+        pool = self.pools.first()
 
-        subnet = self.subnets.get(name=subnet_name)
-        pool = self.pools.get(name=pool_name)
-        networks = [{'subnets': [subnet, ]}, ]
         api.lbaas.pool_get(
             IsA(http.HttpRequest), pool.id).MultipleTimes().AndReturn(pool)
 
         api.neutron.subnet_get(
             IsA(http.HttpRequest), subnet.id).AndReturn(subnet)
 
-        api.neutron.network_list_for_tenant(
-            IsA(http.HttpRequest), self.tenant.id).AndReturn(networks)
-
         params = {'name': vip.name,
                   'description': vip.description,
                   'pool_id': vip.pool_id,
                   'address': vip.address,
-                  'subnet_id': pool.subnet_id,
+                  'floatip_address': vip.floatip_address,
+                  'other_address': vip.other_address,
+                  'subnet': vip.subnet,
+                  'subnet_id': vip.subnet_id,
                   'protocol_port': vip.protocol_port,
                   'protocol': vip.protocol,
                   'session_persistence': vip.session_persistence['type'],
@@ -357,8 +301,6 @@ class LoadBalancerTests(test.TestCase):
                   }
         if with_conn_limit:
             params['connection_limit'] = vip.connection_limit
-        if with_diff_subnet:
-            params['subnet_id'] = vip.subnet_id
         api.lbaas.vip_create(
             IsA(http.HttpRequest), **params).AndReturn(vip)
 
@@ -369,7 +311,10 @@ class LoadBalancerTests(test.TestCase):
             'description': vip.description,
             'pool_id': vip.pool_id,
             'address': vip.address,
-            'subnet_id': pool.subnet_id,
+            'floatip_address': vip.floatip_address,
+            'other_address': vip.other_address,
+            'subnet_id': vip.subnet_id,
+            'subnet': vip.subnet,
             'protocol_port': vip.protocol_port,
             'protocol': vip.protocol,
             'session_persistence': vip.session_persistence['type'].lower(),
@@ -378,9 +323,6 @@ class LoadBalancerTests(test.TestCase):
         if with_conn_limit:
             form_data['connection_limit'] = vip.connection_limit
 
-        if with_diff_subnet:
-            params['subnet_id'] = vip.subnet_id
-
         res = self.client.post(
             reverse(self.ADDVIP_PATH, args=(pool.id,)), form_data)
 
@@ -388,22 +330,17 @@ class LoadBalancerTests(test.TestCase):
         self.assertRedirectsNoFollow(res, str(self.INDEX_URL))
 
     @test.create_stubs({api.lbaas: ('pool_get', ),
-                        api.neutron: (
-                            'network_list_for_tenant', 'subnet_get', )})
+                        api.neutron: ('subnet_get', )})
     def test_add_vip_post_with_error(self):
         vip = self.vips.first()
 
         subnet = self.subnets.first()
         pool = self.pools.first()
-        networks = [{'subnets': [subnet, ]}, ]
 
         api.lbaas.pool_get(IsA(http.HttpRequest), pool.id).AndReturn(pool)
         api.neutron.subnet_get(
             IsA(http.HttpRequest), subnet.id).AndReturn(subnet)
 
-        api.neutron.network_list_for_tenant(
-            IsA(http.HttpRequest), self.tenant.id).AndReturn(networks)
-
         self.mox.ReplayAll()
 
         form_data = {
@@ -411,7 +348,7 @@ class LoadBalancerTests(test.TestCase):
             'description': vip.description,
             'pool_id': vip.pool_id,
             'address': vip.address,
-            'subnet_id': pool.subnet_id,
+            'subnet_id': vip.subnet_id,
             'protocol_port': 65536,
             'protocol': vip.protocol,
             'session_persistence': vip.session_persistence['type'].lower(),
@@ -424,27 +361,16 @@ class LoadBalancerTests(test.TestCase):
 
         self.assertFormErrors(res, 2)
 
-    def test_add_vip_get(self):
-        self._test_add_vip_get()
-
-    def test_add_vip_get_with_diff_subnet(self):
-        self._test_add_vip_get(with_diff_subnet=True)
-
     @test.create_stubs({api.lbaas: ('pool_get', ),
-                        api.neutron: (
-                            'network_list_for_tenant', 'subnet_get', )})
-    def _test_add_vip_get(self, with_diff_subnet=False):
+                        api.neutron: ('subnet_get', )})
+    def test_add_vip_get(self):
         subnet = self.subnets.first()
         pool = self.pools.first()
-        networks = [{'subnets': [subnet, ]}, ]
 
         api.lbaas.pool_get(IsA(http.HttpRequest), pool.id).AndReturn(pool)
         api.neutron.subnet_get(
             IsA(http.HttpRequest), subnet.id).AndReturn(subnet)
 
-        api.neutron.network_list_for_tenant(
-            IsA(http.HttpRequest), self.tenant.id).AndReturn(networks)
-
         self.mox.ReplayAll()
 
         res = self.client.get(reverse(self.ADDVIP_PATH, args=(pool.id,)))
@@ -456,9 +382,6 @@ class LoadBalancerTests(test.TestCase):
         expected_objs = ['<AddVipStep: addvipaction>', ]
         self.assertQuerysetEqual(workflow.steps, expected_objs)
 
-        if with_diff_subnet:
-            self.assertNotEqual(networks[0], pool.subnet_id)
-
     @test.create_stubs({api.lbaas: ('pool_health_monitor_create', )})
     def test_add_monitor_post(self):
         monitor = self.monitors.first()
@@ -530,100 +453,69 @@ class LoadBalancerTests(test.TestCase):
     def test_add_member_post_without_weight(self):
         self._test_add_member_post(with_weight=False)
 
-    def test_add_member_post_without_server_list(self):
-        self._test_add_member_post(with_server_list=False)
-
     def test_add_member_post_multiple_ports(self):
         self._test_add_member_post(mult_ports=True)
 
     @test.create_stubs({api.lbaas: ('pool_list', 'pool_get', 'member_create'),
                         api.neutron: ('port_list',),
                         api.nova: ('server_list',)})
-    def _test_add_member_post(self, with_weight=True, with_server_list=True,
-                              mult_ports=False):
+    def _test_add_member_post(self, with_weight=True, mult_ports=False):
         member = self.members.first()
+
         server1 = self.AttributeDict({'id':
                                       '12381d38-c3eb-4fee-9763-12de3338042e',
                                       'name': 'vm1'})
         server2 = self.AttributeDict({'id':
                                       '12381d38-c3eb-4fee-9763-12de3338043e',
                                       'name': 'vm2'})
+        pool = self.pools.list()[1]
+        port1 = self.AttributeDict(
+            {'fixed_ips': [{'ip_address': member.address,
+                            'subnet_id':
+                            'e8abc972-eb0c-41f1-9edd-4bc6e3bcd8c9'}],
+             'network_id': '82288d84-e0a5-42ac-95be-e6af08727e42'})
 
         api.lbaas.pool_list(IsA(http.HttpRequest), tenant_id=self.tenant.id) \
             .AndReturn(self.pools.list())
+
         api.nova.server_list(IsA(http.HttpRequest)).AndReturn(
             [[server1, server2], False])
 
-        if with_server_list:
-            pool = self.pools.list()[1]
-            port1 = self.AttributeDict(
-                {'fixed_ips': [{'ip_address': member.address,
-                                'subnet_id':
-                                'e8abc972-eb0c-41f1-9edd-4bc6e3bcd8c9'}],
-                 'network_id': '82288d84-e0a5-42ac-95be-e6af08727e42'})
+        api.lbaas.pool_get(
+            IsA(http.HttpRequest), pool.id).AndReturn(pool)
 
-            api.lbaas.pool_get(
-                IsA(http.HttpRequest), pool.id).AndReturn(pool)
-            if mult_ports:
-                port2 = self.AttributeDict(
-                    {'fixed_ips': [{'ip_address': '172.16.88.12',
-                                    'subnet_id':
-                                    '3f7c5d79-ee55-47b0-9213-8e669fb03009'}],
-                     'network_id': '72c3ab6c-c80f-4341-9dc5-210fa31ac6c2'})
-                api.neutron.port_list(
-                    IsA(http.HttpRequest),
-                    device_id=server1.id).AndReturn([port1, port2])
-            else:
-                api.neutron.port_list(
-                    IsA(http.HttpRequest),
-                    device_id=server1.id).AndReturn([port1, ])
+        if mult_ports:
+            port2 = self.AttributeDict(
+                {'fixed_ips': [{'ip_address': '172.16.88.12',
+                                'subnet_id':
+                                '3f7c5d79-ee55-47b0-9213-8e669fb03009'}],
+                 'network_id': '72c3ab6c-c80f-4341-9dc5-210fa31ac6c2'})
+            api.neutron.port_list(IsA(http.HttpRequest),
+                device_id=server1.id).AndReturn([port1, port2])
+        else:
+            api.neutron.port_list(IsA(http.HttpRequest),
+                device_id=server1.id).AndReturn([port1, ])
+
+        params = {'pool_id': member.pool_id,
+                  'address': member.address,
+                  'protocol_port': member.protocol_port,
+                  'members': [server1.id],
+                  'admin_state_up': member.admin_state_up,
+                  }
+        if with_weight:
+            params['weight'] = member.weight
+        api.lbaas.member_create(IsA(http.HttpRequest),
+                                **params).AndReturn(member)
+
+        self.mox.ReplayAll()
 
         form_data = {'pool_id': member.pool_id,
+                     'address': member.address,
                      'protocol_port': member.protocol_port,
                      'members': [server1.id],
                      'admin_state_up': member.admin_state_up}
         if with_weight:
             form_data['weight'] = member.weight
-        if with_server_list:
-            form_data['member_type'] = 'server_list'
-        else:
-            form_data['member_type'] = 'member_address'
-            form_data['address'] = member.address
-        api.lbaas.member_create(IsA(http.HttpRequest),
-                                **form_data).AndReturn(member)
-
-        self.mox.ReplayAll()
-
-        res = self.client.post(reverse(self.ADDMEMBER_PATH), form_data)
-
-        self.assertNoFormErrors(res)
-        self.assertRedirectsNoFollow(res, str(self.INDEX_URL))
-
-    @test.create_stubs({api.lbaas: ('pool_list', 'pool_get', 'member_create'),
-                        api.neutron: ('port_list',),
-                        api.nova: ('server_list',)})
-    def test_add_member_no_ports(self):
-        member = self.members.first()
-        pools = self.pools.list()
-        server1 = self.AttributeDict({'id':
-                                      '12381d38-c3eb-4fee-9763-12de3338042e',
-                                      'name': 'vm1'})
-        api.lbaas.pool_list(
-            IsA(http.HttpRequest), tenant_id=self.tenant.id).AndReturn(pools)
-        api.nova.server_list(
-            IsA(http.HttpRequest)).AndReturn([[server1, ], False])
-        api.lbaas.pool_get(
-            IsA(http.HttpRequest), pools[1].id).AndReturn(pools[1])
-        api.neutron.port_list(
-            IsA(http.HttpRequest), device_id=server1.id).AndReturn([])
-
-        form_data = {'pool_id': member.pool_id,
-                     'protocol_port': member.protocol_port,
-                     'members': [server1.id],
-                     'admin_state_up': member.admin_state_up,
-                     'member_type': 'server_list'}
-
-        self.mox.ReplayAll()
 
         res = self.client.post(reverse(self.ADDMEMBER_PATH), form_data)
 
@@ -647,7 +539,7 @@ class LoadBalancerTests(test.TestCase):
 
         api.nova.server_list(IsA(http.HttpRequest)).AndReturn([[server1,
                                                                 server2],
-                                                               False])
+                                                                False])
 
         self.mox.ReplayAll()
 
@@ -706,7 +598,7 @@ class LoadBalancerTests(test.TestCase):
         self.mox.ReplayAll()
 
         form_data = data.copy()
-        form_data['pool_id'] = pool.id
+        form_data.update({'pool_id': pool.id})
 
         res = self.client.post(
             reverse(self.UPDATEPOOL_PATH, args=(pool.id,)), form_data)
@@ -748,7 +640,7 @@ class LoadBalancerTests(test.TestCase):
         self.mox.ReplayAll()
 
         form_data = data.copy()
-        form_data['vip_id'] = vip.id
+        form_data.update({'vip_id': vip.id})
 
         res = self.client.post(
             reverse(self.UPDATEVIP_PATH, args=(vip.id,)), form_data)
@@ -790,7 +682,7 @@ class LoadBalancerTests(test.TestCase):
         self.mox.ReplayAll()
 
         form_data = data.copy()
-        form_data['member_id'] = member.id
+        form_data.update({'member_id': member.id})
 
         res = self.client.post(
             reverse(self.UPDATEMEMBER_PATH, args=(member.id,)), form_data)
@@ -827,14 +719,13 @@ class LoadBalancerTests(test.TestCase):
                 'max_retries': monitor.max_retries,
                 'admin_state_up': monitor.admin_state_up}
 
-        api.lbaas.pool_health_monitor_update(
-            IsA(http.HttpRequest),
+        api.lbaas.pool_health_monitor_update(IsA(http.HttpRequest),
             monitor.id, health_monitor=data).AndReturn(monitor)
 
         self.mox.ReplayAll()
 
         form_data = data.copy()
-        form_data['monitor_id'] = monitor.id
+        form_data.update({'monitor_id': monitor.id})
 
         res = self.client.post(
             reverse(self.UPDATEMONITOR_PATH, args=(monitor.id,)), form_data)
@@ -860,7 +751,7 @@ class LoadBalancerTests(test.TestCase):
     @test.create_stubs({api.lbaas: ('pool_get', 'pool_health_monitor_list',
                                     'pool_monitor_association_create')})
     def test_add_pool_monitor_association_post(self):
-        pool = self.pools.list()[1]
+        pool = self.pools.first()
         monitors = self.monitors.list()
         monitor = self.monitors.list()[1]
 
@@ -957,20 +848,12 @@ class LoadBalancerTests(test.TestCase):
             '<DeletePMAssociationStep: deletepmassociationaction>', ]
         self.assertQuerysetEqual(workflow.steps, expected_objs)
 
-    @test.create_stubs({api.lbaas: ('pool_list', 'pool_delete'),
-                        api.network: ('tenant_floating_ip_list',)})
+    @test.create_stubs({api.lbaas: ('pool_list', 'member_list',
+                                    'pool_health_monitor_list',
+                                    'pool_delete')})
     def test_delete_pool(self):
-        pool_list = self.pools.list()
-        pool = pool_list[0]
-        fips = self.floating_ips.list()
-        # the test pool needs to have no vip
-        # in order to be able to be deleted
-        pool.vip_id = None
-        api.lbaas.pool_list(
-            IsA(http.HttpRequest), tenant_id=self.tenant.id) \
-            .AndReturn(pool_list)
-        api.network.tenant_floating_ip_list(IsA(http.HttpRequest)).\
-            AndReturn(fips)
+        self.set_up_expect()
+        pool = self.pools.first()
         api.lbaas.pool_delete(IsA(http.HttpRequest), pool.id)
         self.mox.ReplayAll()
 
@@ -979,27 +862,14 @@ class LoadBalancerTests(test.TestCase):
 
         self.assertNoFormErrors(res)
 
-    @test.create_stubs({api.lbaas: ('pool_list', 'pool_get',
-                                    'member_list', 'vip_delete',
-                                    'pool_health_monitor_list'),
-                        api.network: (
-                            'tenant_floating_ip_list',
-                            'floating_ip_supported',
-                            'floating_ip_simple_associate_supported')})
+    @test.create_stubs({api.lbaas: ('pool_list', 'member_list',
+                                    'pool_health_monitor_list',
+                                    'pool_get', 'vip_delete')})
     def test_delete_vip(self):
+        self.set_up_expect()
         pool = self.pools.first()
         vip = self.vips.first()
-        fips = self.floating_ips.list()
-        api.lbaas.pool_list(
-            IsA(http.HttpRequest), tenant_id=self.tenant.id) \
-            .AndReturn(self.pools.list())
         api.lbaas.pool_get(IsA(http.HttpRequest), pool.id).AndReturn(pool)
-        api.network.floating_ip_supported(IgnoreArg()).MultipleTimes() \
-            .AndReturn(True)
-        api.network.floating_ip_simple_associate_supported(IgnoreArg()) \
-            .MultipleTimes().AndReturn(True)
-        api.network.tenant_floating_ip_list(IsA(http.HttpRequest)).\
-            AndReturn(fips)
         api.lbaas.vip_delete(IsA(http.HttpRequest), vip.id)
         self.mox.ReplayAll()
 
@@ -1008,27 +878,12 @@ class LoadBalancerTests(test.TestCase):
 
         self.assertNoFormErrors(res)
 
-    @test.create_stubs({api.lbaas: ('pool_get', ),
-                        api.network: ('tenant_floating_ip_list',
-                                      'floating_ip_disassociate', )})
-    def test_disassociate_vip_fip(self):
-        pool = self.pools.first()
-        fips = self.floating_ips.list()
-        api.lbaas.pool_get(IsA(http.HttpRequest), pool.id).AndReturn(pool)
-        api.network.tenant_floating_ip_list(IsA(http.HttpRequest)).\
-            AndReturn(fips)
-        api.network.floating_ip_disassociate(IsA(http.HttpRequest), 3)
-        self.mox.ReplayAll()
-        form_data = {"action": "poolstable__disassociate__%s" % pool.id}
-        res = self.client.post(self.INDEX_URL, form_data)
-        self.assertNoFormErrors(res)
-
-    @test.create_stubs({api.lbaas: ('member_list', 'member_delete')})
+    @test.create_stubs({api.lbaas: ('pool_list', 'member_list',
+                                    'pool_health_monitor_list',
+                                    'member_delete')})
     def test_delete_member(self):
+        self.set_up_expect()
         member = self.members.first()
-        api.lbaas.member_list(
-            IsA(http.HttpRequest), tenant_id=self.tenant.id) \
-            .AndReturn(self.members.list())
         api.lbaas.member_delete(IsA(http.HttpRequest), member.id)
         self.mox.ReplayAll()
 
@@ -1037,13 +892,12 @@ class LoadBalancerTests(test.TestCase):
 
         self.assertNoFormErrors(res)
 
-    @test.create_stubs({api.lbaas: ('pool_health_monitor_list',
+    @test.create_stubs({api.lbaas: ('pool_list', 'member_list',
+                                    'pool_health_monitor_list',
                                     'pool_health_monitor_delete')})
     def test_delete_monitor(self):
+        self.set_up_expect()
         monitor = self.monitors.first()
-        api.lbaas.pool_health_monitor_list(
-            IsA(http.HttpRequest), tenant_id=self.tenant.id).MultipleTimes() \
-            .AndReturn(self.monitors.list())
         api.lbaas.pool_health_monitor_delete(IsA(http.HttpRequest), monitor.id)
         self.mox.ReplayAll()
 
