@@ -25,7 +25,7 @@ class FakeUser(object):
 
 
 class TemplateRenderTest(test.TestCase):
-    """ Tests for templates render """
+    """Tests for templates render."""
 
     def test_openrc_html_escape(self):
         context = {
@@ -69,3 +69,30 @@ class TemplateRenderTest(test.TestCase):
         self.assertFalse('o\"' in out)
         self.assertFalse('o"' in out)
         self.assertTrue('\\"' in out)
+
+    def test_openrc_set_region(self):
+        context = {
+            "user": FakeUser(),
+            "tenant_id": "some-cool-id",
+            "auth_url": "http://tests.com",
+            "tenant_name": "Tenant",
+            "region": "Colorado"}
+        out = loader.render_to_string(
+            'project/access_and_security/api_access/openrc.sh.template',
+            context,
+            template.Context(context))
+
+        self.assertTrue("OS_REGION_NAME=\"Colorado\"" in out)
+
+    def test_openrc_region_not_set(self):
+        context = {
+            "user": FakeUser(),
+            "tenant_id": "some-cool-id",
+            "auth_url": "http://tests.com",
+            "tenant_name": "Tenant"}
+        out = loader.render_to_string(
+            'project/access_and_security/api_access/openrc.sh.template',
+            context,
+            template.Context(context))
+
+        self.assertTrue("OS_REGION_NAME=\"\"" in out)
